# <div dir="rtl">pySentiPers</div>
<div dir="rtl">
Python API for SentiPers Dataset - رابط برنامه‌نویسی کاربردی پایتون مجموعه داده‌ی سنتی‌پرس
</div>

## <div dir="rtl">مقدمه</div>

<div dir="rtl">
پروژه‌ای که مشاهده می‌کنید یک API برای استفاده‌ی راحت‌تر از دیتاست سنتی‌پرس(SentiPers) به زبان پایتون می‌باشد. این مجموعه دادگان در گروه پردازش زبان‌های طبیعی دانشگاه گیلان به کوشش پدرام حسینی و همکاران تهیه شده است و در پایگاه دادگان به آدرس http://dadegan.ir/catalog/sentipers اطلاعات بیشتری قابل مشاهده است.
</div>

## <div dir="rtl">توضیحات</div>
<div dir="rtl">
برای تهیه‌ی مجموعه به لینک بالا مراجعه کنید، این پروژه صرفا API پایتون برای کار با مجموعه دادگان می‌باشد.
پروژه‌ی حاضر توسط جواد زارع‌زاده نوشته شده است. چنانچه هم‌فکری و یا درخواستی برای اصلاح کد داشتید خوشحال خواهم شد با ایمیل زیر با من در ارتباط باشید.
email: jayzee1992@gmail.com
</div>
